#pysynphot examples
#
#initial setup and cleanup
#
import os

os.environ['PYSYN_CDBS'] = '/Users/jmiller/cdbs'
import pysynphot as ps
import pylab as pl
import numpy as np

#
#
# Setup: Required environment variable, pysynphot, pylab
#
flist=['f555w', 'f606w', 'f625w']
for filt in flist:
   obsmode='acs,hrc,%s'%filt
   print obsmode

#Create some Spectra

gauss = ps.GaussianSource(1.5e-13, 5000, 2)
pl.clf(); pl.plot(gauss.wave, gauss.flux, '.-')
pl.xlim(4990,5015)

bb = ps.BlackBody(6000)
pl.clf(); pl.plot(bb.wave,bb.flux,'.-')

pl.xlim(4990,5015)

spect = 100*bb + gauss

#Evaluate the composite at evenly-spaced samples
#
warr = np.arange(5000.)+3000 # define wavelengths to evaluate at
pl.clf(); pl.plot(warr, spect(warr),'.-')

pl.xlim(4990,5015)

#Evaluate at pysynphot-native samples
pl.clf(); pl.plot(spect.wave,spect.flux,'.-')

pl.xlim(4990,5015)

#See different wavesets
gauss.wave
bb.wave
len(gauss.wave), len(bb.wave), len(spect.wave)

#See component structure
spect.component2
spect.component1
spect.component1.component1
spect.component1.component2

#Make some more
gauss2 = ps.GaussianSource(1.e-11, 6000, 50)
spect2 = 100*bb + gauss + gauss2
pl.clf(); pl.plot(spect2.wave, spect2.flux)
spect3 = 100*bb + gauss.redshift(.3) + gauss2
pl.clf(); pl.plot(spect3.wave, spect3.flux)
pl.xlabel(spect3.waveunits); pl.ylabel(spect3.fluxunits)

spect3.integrate()

#Read in vega & show some unit transformations
vega = ps.FileSpectrum(
    os.environ['PYSYN_CDBS'] + '/calspec/alpha_lyr_stis_003.fits')

pl.clf(); pl.plot(vega.wave,vega.flux); pl.xlim(0,20000)
pl.xlabel(vega.waveunits); pl.ylabel(vega.fluxunits)

vega.convert('photlam')
pl.clf(); pl.plot(vega.wave,vega.flux); pl.xlim(0,20000)
pl.xlabel(vega.waveunits); pl.ylabel(vega.fluxunits)

vega.convert('fnu')
pl.clf(); pl.plot(vega.wave,vega.flux); pl.xlim(0,20000)
pl.xlabel(vega.waveunits); pl.ylabel(vega.fluxunits)

vega.convert('vegamag')
pl.clf(); pl.plot(vega.wave,vega.flux); pl.xlim(0,20000)
pl.xlabel(vega.waveunits); pl.ylabel(vega.fluxunits)

#Make a spectral element
hstband = ps.ObsBandpass('acs,hrc,f555w')
pl.clf(); pl.plot(hstband.wave,hstband.throughput)
pl.xlim(4500,6500)

#"observe" vega through it
vega.convert('flam')
pl.clf(); pl.plot(vega.wave, vega.flux); pl.xlim(0,20000)
obs=ps.Observation(vega,hstband)
obs.convert('flam')
pl.plot(obs.binwave,obs.binflux); pl.xlim(0,20000)
pl.xlabel(obs.waveunits); pl.ylabel(obs.fluxunits)

obs.convert('counts')
pl.clf(); pl.plot(obs.binwave,obs.binflux,linestyle='steps')
pl.xlim(4500,6500); pl.xlabel(obs.waveunits); pl.ylabel(obs.fluxunits)
obs.countrate()

#Integrate over a coarser binning
coarsebins=np.arange(4500,6500,20)
obs2=ps.Observation(vega,hstband,binset=coarsebins)
obs2.convert('counts')
pl.clf(); pl.plot(obs2.binwave,obs2.binflux,linestyle='steps')
pl.xlabel(obs2.waveunits); pl.ylabel(obs2.fluxunits)

#Renormalization
bb.convert('flam')
pl.clf();pl.plot(bb.wave,bb.flux)

bbrn = bb.renorm(1e-15,'flam',hstband)
pl.plot(bbrn.wave,bbrn.flux)
pl.xlabel(bb.waveunits);pl.ylabel(bb.fluxunits)
