"""Constructs a ScriptManager from the doctest contained in the module
docstring of the specified module.

$Id: doctest_manager.py 1027 2009-08-06 15:02:01Z jmiller $
"""
import os, os.path, copy, doctest, sys
from bases import ScriptManager, Exposition

def script_manager_from_doctest(name):
    """Returns a ScriptManager derived from the named module's docstring."""
    module_name, module, context = get_module_and_context(name)
    module_test = get_module_test(module_name, module)
    test_items = get_module_test_items(module_test)
    expositions = get_expositions(test_items)
    return ScriptManager(name, context, expositions)

def get_module_and_context(name):
    """Handles filename -> module_name conversion, module import,
    and creation of execution context by copying module dictionary.
    """
    if name.endswith(".py") or name.endswith(".pyc"):
        name = "".join(name.split(".")[:-1])
    path, module_name = os.path.split(name)
    if path not in sys.path:
        sys.path.append(path)
    context = {}
    exec "import " + module_name in context
    module = context[module_name]
    return module_name, module, copy.copy(module.__dict__)

def get_module_test(module_name, module):
    """Returns the doctest test object associated with 'module'"""
    finder = doctest.DocTestFinder(module)
    for t in finder.find(module):
        if t.name == module_name:
            return t
    else:
        raise RuntimeError("Can't find module test for " + repr(module_name))

def get_module_test_items(module_test):
    """Eliminate white space and return a list of descriptive text
    blocks and doctest Example objects.
    """
    parser = doctest.DocTestParser()
    parsed = parser.parse(module_test.docstring)
    items = []
    for item in parsed:
        if isinstance(item, str):
            item = item.strip()
            if item:
                items.append(item)
        else:  # example
            items.append(item)
    return items

def get_expositions(items):
    """Organizes test items into an Exposition list."""
    expositions = []
    descr = None
    examples = []
    for i in items:
        if isinstance(i, str):
            if examples:
                expositions.append(Exposition(descr, examples))
            descr = i + "\n"
            examples = []
        else:
            examples.append(i)
    else:
        expositions.append(Exposition(descr, examples))
    return expositions
