"""Constructs a ScriptManager from a simple Python script consisting
of alternating #-comments and statements.

$Id: linear_manager.py 1037 2009-08-07 19:03:34Z jmiller $
"""
from bases import ScriptManager, Exposition, Example

def script_manager_from_linear_script(name):

    """Parses a simple linear script specified by name into a list of
    expositions and constructs a ScriptManager from it.
    """

    state = "reading_description"
    description = ""
    expositions = []
    examples = []
    code = ""
    for l in open(name).readlines():
        if l.startswith("#") or l.strip() == "":
            if state == "reading_examples":
                if code.rstrip() != "":
                    examples.append(Example(code))
                if len(examples) == 0:  # always at least one statement
                    examples.append(Example("pass # Cyrano inserted this automatically.\n"))
                expositions.append(Exposition(description, examples))
                state = "reading_description"
                description = l
                examples = []
                code = ""
            else:
                description += l
        else:
            state = "reading_examples"
            if not code:
                code = l
            elif l.rstrip() == "":
                examples.append(Example(code))
                code = l
            elif l.startswith(" ") or l.startswith("\t"):
                code += l
            else:
                examples.append(Example(code))
                code = l
    if code.rstrip() != "":
        examples.append(Example(code))
    if description or examples:
        expositions.append(Exposition(description, examples))
    return ScriptManager(name, {}, expositions)
